@@ -4,8 +4,8 @@ from __future__ import annotations
 
 __title__ = "vcspull"
 __package_name__ = "vcspull"
-__description__ = "Manage and sync multiple git, mercurial, and svn repos"
-__version__ = "1.35.0"
+__description__ = "Repo manager and syncer for git, mercurial, and svn"
+__version__ = "1.41.0"
 __author__ = "Tony Narlock"
 __github__ = "https://github.com/vcs-python/vcspull"
 __docs__ = "https://vcspull.git-pull.com"
